@@ -38,7 +38,7 @@ metainf <- function(x, pooled, sortvar) {
     xd <- x$data
     sortvar <- eval(mf[[match("sortvar", names(mf))]],
                     xd, enclos = NULL)
-    if (!is.null(x$data$.subset))
+    if (isCol(x$data, ".subset"))
       sortvar <- sortvar[x$data$.subset]
   }
   sort <- !is.null(sortvar)
@@ -133,7 +133,9 @@ metainf <- function(x, pooled, sortvar) {
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    keepdata = FALSE,
-                   warn = FALSE)
+                   warn = FALSE,
+                   ##
+                   control = x$control)
     ##
     if (inherits(x, "metacont"))
       m <- metacont(n.e[sel], mean.e[sel], sd.e[sel],
@@ -150,7 +152,9 @@ metainf <- function(x, pooled, sortvar) {
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     keepdata = FALSE,
-                    warn = FALSE)
+                    warn = FALSE,
+                    ##
+                    control = x$control)
     ##
     if (inherits(x, "metacor"))
       m <- metacor(cor[sel], n[sel],
@@ -166,7 +170,9 @@ metainf <- function(x, pooled, sortvar) {
                    method.tau = x$method.tau,
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
-                   keepdata = FALSE)
+                   keepdata = FALSE,
+                   ##
+                   control = x$control)
     ##
     if (inherits(x, "metagen"))
       m <- metagen(TE[sel], seTE[sel],
@@ -183,7 +189,9 @@ metainf <- function(x, pooled, sortvar) {
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    keepdata = FALSE,
-                   warn = FALSE)
+                   warn = FALSE,
+                   ##
+                   control = x$control)
     ##
     if (inherits(x,"metainc"))
       m <- metainc(event.e[sel], time.e[sel],
@@ -203,7 +211,9 @@ metainf <- function(x, pooled, sortvar) {
                    tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                    ##
                    keepdata = FALSE,
-                   warn = FALSE)
+                   warn = FALSE,
+                   ##
+                   control = x$control)
     ##
     if (inherits(x, "metamean"))
       m <- metamean(n[sel], mean[sel], sd[sel],
@@ -220,7 +230,9 @@ metainf <- function(x, pooled, sortvar) {
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     keepdata = FALSE,
-                    warn = FALSE)
+                    warn = FALSE,
+                    ##
+                    control = x$control)
     ##
     if (inherits(x, "metaprop"))
       m <- metaprop(event[sel], n[sel],
@@ -240,7 +252,9 @@ metainf <- function(x, pooled, sortvar) {
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     keepdata = FALSE,
-                    warn = FALSE)
+                    warn = FALSE,
+                    ##
+                    control = x$control)
     ##
     if (inherits(x, "metarate"))
       m <- metarate(event[sel], time[sel],
@@ -259,7 +273,9 @@ metainf <- function(x, pooled, sortvar) {
                     tau.preset = x$tau.preset, TE.tau = x$TE.tau,
                     ##
                     keepdata = FALSE,
-                    warn = FALSE)
+                    warn = FALSE,
+                    ##
+                    control = x$control)
     ##
     sel.pft <- inherits(x, "metaprop") & x$sm == "PFT"
     sel.irft <- inherits(x, "metarate") & x$sm == "IRFT"
